@@ -8,8 +8,7 @@
 #' address, SMTP server url and port number
 #' @param to Character vector containing email addresses. May also contain
 #' full names like '\code{Jane Doe <janed@nowhere.com>}'
-#' @param subject Character string providing email subject. The string is
-#' converted within this function to conform to RFC 1342
+#' @param subject Character string providing email subject.
 #' @param text Character string providing the plain email text
 #' @param attFile Character string providing the full file path to an
 #' attachment. Default is NULL in which case no attachment is made
@@ -21,24 +20,12 @@ sendEmail <- function(conf, to, subject, text, attFile = NULL) {
   if (!is.null(attFile)) {
     stopifnot(file.exists(attFile))
   }
-  # nocov start
 
-  # apply RFC 1342 on headers (i.e. subject)
-  charset <- "=?UTF-8?"
-  enc <- "B?"
-  headPost <- "?="
+  # nocov start
 
   from <- conf$network$sender
   # escape spaces (e.g. when full name is added to <email>)
   to <- gsub(" ", "\\ ", to, fixed = TRUE)
-  # Subject is a header field, hence non-ascii to be base64 encoded
-  # Header lines must be 76 chars or less and split by a space
-  # and contain consistent encoded-word(s)
-  subject <- charToRaw(subject)
-  subject <- base64enc::base64encode(subject, linewidth = 63)
-  subject <- paste(paste0(charset, enc, subject, headPost),
-    collapse = " "
-  )
 
   if (is.null(attFile)) {
     body <- list(text)
